@@ -107,7 +107,7 @@ TRUSTS_INFOS = {
 	"PIM_TRUST": 0x400
 }
 
-WELL_KNOWN_SIDs = {
+WELL_KNOWN_SIDS = {
 	"S-1-5-32-544"	: r"BUILTIN\Administrators",
 	"S-1-5-32-545"	: r"BUILTIN\Users",
 	"S-1-5-32-546"	: r"BUILTIN\Guests",
@@ -164,3 +164,5 @@ DATETIME_FIELDS = [
 ]
 
 LDAP_SERVER_SD_FLAGS_OID_SEC_DESC = [('1.2.840.113556.1.4.801', True, b'\x30\x03\x02\x01\x07')]
+
+LOGON_SAM_LOGON_RESPONSE_EX = b'\x17\x00'
